#include <stdio.h>
#include <bastard.h>

/* usage: bdbdump bdb_file [table] */

int print_usage()
{
	printf("bdbview bdb_file\n");
	return (1);
}

int main(int argc, char **argv)
{
	char base[PATH_MAX];
	int x;

	if (argc < 2)
		return (print_usage());

	/* init bastard */
	if (!sys_find_base(base, PATH_MAX, argv))
		return (-1);

	sys_init(base);

	/* get bdb filename */
	target_load_bdb(argv[1]);
	schema = db_schema_by_name("TARGET");

	/* close bastard */
	target_close_db();
	sys_quit();
	return (0);
}
